#!/bin/bash
# Copyright Indexima
#
# Start deploying Indexima as a YARN application
#

mandatory_files=("galactica-env.sh" "hive-site.xml" "galactica.conf")

for file in ${mandatory_files[@]}; do
  if [ ! -r "./conf/$file" ] ; then
	  echo "The file conf/$file is not found. Please create it based on the template file.";
    exit 1;
  fi
done

export GALACTICA_LIB=indexima-core-2024.1.1795.0.jar


. conf/galactica-env.sh
. conf/galactica-common.sh

if [ ! -z "${KINIT_FROM_HIVE_SITE}" ] ; then
        echo "Extract principal and keytab from hive-site.xml"
        KINIT_PRINCIPAL=`grep -A1 hive.server2.authentication.kerberos.principal ./conf/hive-site.xml | grep value | sed -e 's/<value>\(.*\)<\/value>/\1/' -e "s/_HOST/$(hostname -f)/" -e 's/ //g'`
        KINIT_KEYTAB=`grep -A1 hive.server2.authentication.kerberos.keytab ./conf/hive-site.xml | grep value | sed -e 's/<value>\(.*\)<\/value>/\1/' -e 's/ //g'`
fi

if [ ! -z "${KINIT_PRINCIPAL}" ] && [ ! -z "${KINIT_KEYTAB}" ] ; then
        echo "Trying to kinit with ${KINIT_PRINCIPAL} and ${KINIT_KEYTAB}"
        kinit -kt ${KINIT_KEYTAB} ${KINIT_PRINCIPAL}
        if [ $? -ne 0 ] ; then
                echo "Unable to do kinit, Indexima/Galactica is not started";
                exit 1;
        fi
fi

export JAVA_HOME=${JAVA_HOME:-"$(dirname $(which java))/.."}

$JAVA_HOME/bin/java -Xms32m -Xmx32m -XX:+UseConcMarkSweepGC $JMX_OPTIONS -cp $ORDER_LIBS:lib/*:lib/postcp/*:driver/*:conf:$GALACTICA_LIB:$HADOOP_JARS io.galactica.yarn.GaYarnLauncher $@
